summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorValentin Rothberg <vrothberg@redhat.com>2022-08-03 13:00:27 +0200
committerValentin Rothberg <vrothberg@redhat.com>2022-08-04 13:07:58 +0200
commitcfa089c361c697932f0cd5506a1a43077253d6c8 (patch)
tree506c06ebc7be8d01f8f22cf6ae718c629f19a75c
parent13a8ebd09f7d76d43f1b8af86c7ca2bbc1acfbca (diff)
downloadpodman-cfa089c361c697932f0cd5506a1a43077253d6c8.tar.gz
podman-cfa089c361c697932f0cd5506a1a43077253d6c8.tar.bz2
podman-cfa089c361c697932f0cd5506a1a43077253d6c8.zip
pkg/autoupdate: s/updateImage/pullImage/
"pull" is more expressive. Signed-off-by: Valentin Rothberg <vrothberg@redhat.com>
-rw-r--r--pkg/autoupdate/autoupdate.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/autoupdate/autoupdate.go b/pkg/autoupdate/autoupdate.go
index dfdbcc956..d01695912 100644
--- a/pkg/autoupdate/autoupdate.go
+++ b/pkg/autoupdate/autoupdate.go
@@ -258,7 +258,7 @@ func (u *updater) updateRegistry(ctx context.Context, task *task) (*entities.Aut
return report, nil
}
- if _, err := updateImage(ctx, u.runtime, rawImageName, authfile); err != nil {
+ if _, err := pullImage(ctx, u.runtime, rawImageName, authfile); err != nil {
return report, fmt.Errorf("registry auto-updating container %q: image update for %q failed: %w", cid, rawImageName, err)
}
u.updatedRawImages[rawImageName] = true
@@ -474,8 +474,8 @@ func newerLocalImageAvailable(runtime *libpod.Runtime, img *libimage.Image, rawI
return localImg.Digest().String() != img.Digest().String(), nil
}
-// updateImage pulls the specified image.
-func updateImage(ctx context.Context, runtime *libpod.Runtime, name, authfile string) (*libimage.Image, error) {
+// pullImage pulls the specified image.
+func pullImage(ctx context.Context, runtime *libpod.Runtime, name, authfile string) (*libimage.Image, error) {
pullOptions := &libimage.PullOptions{}
pullOptions.AuthFilePath = authfile
pullOptions.Writer = os.Stderr